Software Heritage virtual filesystem (SwhFS)
============================================

Virtual filesystem to browse the `Software Heritage
<https://www.softwareheritage.org/>`_ `archive
<https://archive.softwareheritage.org/>`_, using the `FUSE
<https://github.com/libfuse/libfuse>`_ framework.
